@@ -373,15 +373,6 @@ is used in `matlab-ts-mode--ei-spacing'"
                new-line-no-spaces-or-commas orig-line-no-spaces-or-commas
                (line-number-at-pos (point)) (buffer-name))))))
 
-(defun matlab--ei-offset (&optional pt)
-  "Character based column offset in line, starting at 0.
-If optional point, PT is specified, return line offset for PT, otherwise
-the current `point'.  This is like `current-column' but character based
-and not \"visual\" based."
-  (if pt
-      (- pt (save-excursion (goto-char pt) (pos-bol)))
-    (- (point) (pos-bol))))
-  
 (defvar-local matlab--eilb nil) ;; Buffer used to create new electric indent line, ei-line
 
 (defmacro matlab--eilb-length ()
@@ -462,8 +453,7 @@ N-SPACES-TO-APPEND is the number of spaces to append between nodes."
         (when (> n-spaces-to-append 0)
           (insert (make-string n-spaces-to-append ? )))))))
 
-(defvar matlab-ts-mode--ei-error-query (when (treesit-available-p)
-                                         (treesit-query-compile 'matlab '((ERROR) @e))))
+(defvar matlab-ts-mode--ei-error-query (treesit-query-compile 'matlab '((ERROR) @e)))
 (defvar-local matlab-ts-mode--ei-errors-alist nil)
 
 ;; matlab-ts-mode--ei-tmp-buf-indent is non-nil if doing m-matrix indent (in this case we know there
@@ -518,7 +508,7 @@ Assumes that current point is at `back-to-indentation'."
       ;; Make invisible comma visible by returning it.
       ",")
 
-     ;; Case: invisible comma to insert at end of array row
+     ;; Case: invisible comma to insert at at end of array row
      ;;           foo = {'one', 'two' ...
      ;;                              ^   missing comma, return a comma to have it inserted
      ((and (string= node-type "line_continuation")
@@ -809,7 +799,7 @@ If tmp T-MATRIX-NODE is non-nil, we use that to locate the first row."
         ;; [1, 2, 3;      // child 0 is the '[', child 1 is the first row
         ;;  4, 5, 6]
         ;; [ ...          // child 0 is the '[', child 1 is line_continuation
-        ;;  1, 2, 3;
+        ;;  1, 2, 3;      
         ;;  4, 5, 6]
         (let ((child1 (treesit-node-child t-matrix-node 1)))
           (when (and (string= (treesit-node-type child1) "row")
@@ -844,17 +834,12 @@ If tmp T-MATRIX-NODE is non-nil, we use that to locate the first row."
 ;; Internal variable that shouldn't be altered. It's used to avoid infinite recursion.
 (defvar matlab-ts-mode--ei-align-enabled t)
 
-(defun matlab-ts-mode--ei-indent-matrix-in-tmp-buf (assign-node
-                                                    t-buf-start-pt-linenum start-pt-offset)
+(defun matlab-ts-mode--ei-indent-matrix-in-tmp-buf (assign-node)
   "Insert ASSIGN-NODE in to current tmp-buf and indent.
-T-BUF-START-PT-LINENUM and START-PT-OFFSET are used to place the point
-prior to electric indent without alignment in the tmp buf.
-
 Point is left at beginning of line containing the ASSIGN-NODE text.
 Returns the line number after the ASSIGN-NODE in the tmp-buf."
   (let (assign-str
         assign-end-linenum
-        t-buf-start-pt-offset
         n-levels
         (n-extra-levels 0)
         (is-prop (treesit-parent-until assign-node (rx bos (or "properties" "arguments") eos))))
@@ -897,15 +882,7 @@ Returns the line number after the ASSIGN-NODE in the tmp-buf."
           ;; want to capture the messages from this temp indent-region.
           (treesit--indent-verbose nil))
       (matlab--eilb-setup)
-      (when t-buf-start-pt-linenum
-        (goto-char (point-min))
-        (forward-line (1- t-buf-start-pt-linenum))
-        (move-to-column start-pt-offset))
-
-      (matlab-ts-mode--ei-indent-region (point-min) (point-max))
-
-      (when t-buf-start-pt-linenum
-        (setq t-buf-start-pt-offset (matlab--ei-offset))))
+      (indent-region (point-min) (point-max)))
 
     (goto-char (point-min))
     (forward-line n-levels) ;; Leave point at assignment start
@@ -916,33 +893,24 @@ Returns the line number after the ASSIGN-NODE in the tmp-buf."
                            (goto-char (point-min))
                            (forward-line assign-end-linenum))))
           (string-rectangle start-point end-point (make-string (* n-extra-levels 4) ? )))))
-    (cons assign-end-linenum t-buf-start-pt-offset)))
+    assign-end-linenum))
 
 ;; This is used to cache matrix alignments for indent-region
 ;; It will be non-nil when called from indent-region.
 (defvar-local matlab-ts-mode--ei-align-matrix-alist nil)
 
-(cl-defun matlab-ts-mode--ei-align-line-in-m-matrix (assign-node
-                                                     ei-info
-                                                     &optional start-pt-linenum start-pt-offset)
+(cl-defun matlab-ts-mode--ei-align-line-in-m-matrix (assign-node ei-info)
   "Align current line with EI-INFO in a multi-line matrix of ASSIGN-NODE.
-See `matlab-ts-mode--ei-get-new-line' for EI-INFO contents.  Optional
-START-PT-LINENUM and START-PT-OFFSET give point prior to electric indent
-region.  START-PT-LINENUM may be different from current line."
-  (let* ((matrix-alist matlab-ts-mode--ei-align-matrix-alist) ;; non-nil if indenting a region
+See `matlab-ts-mode--ei-get-new-line' for EI-INFO contents."
+  (let* ((matrix-alist matlab-ts-mode--ei-align-matrix-alist)
          (assign-start-linenum (line-number-at-pos (treesit-node-start assign-node)))
-         (t-buf-start-pt-linenum (when start-pt-linenum
-                                   (1+ (- start-pt-linenum assign-start-linenum))))
          (t-buf-ei-linenum (1+ (- (line-number-at-pos) assign-start-linenum)))
          (t-buf-row-linenum (if matlab-ts-mode--ei-align-matrix-alist 1 t-buf-ei-linenum)))
     (with-temp-buffer
       (unwind-protect
           (progn
             (let* (t-curr-linenum
-                   (tmp-buf-info (matlab-ts-mode--ei-indent-matrix-in-tmp-buf
-                                  assign-node t-buf-start-pt-linenum start-pt-offset))
-                   (t-end-linenum (car tmp-buf-info))
-                   (t-buf-start-pt-offset (cdr tmp-buf-info))
+                   (t-end-linenum (matlab-ts-mode--ei-indent-matrix-in-tmp-buf assign-node))
                    (t-assign-node (save-excursion
                                     (matlab-ts-mode--ei-fast-back-to-indentation)
                                     (treesit-parent-until (treesit-node-at (point) 'matlab)
@@ -950,13 +918,14 @@ region.  START-PT-LINENUM may be different from current line."
                    (t-matrix-node (if t-assign-node
                                       (treesit-node-child-by-field-name t-assign-node "right")
                                     (treesit-node-parent (treesit-search-subtree ;; else a property
-                                                          (treesit-buffer-root-node)
-                                                          (rx bos "[" eos) nil t))))
+                                                        (treesit-buffer-root-node)
+                                                        (rx bos "[" eos) nil t))))
                    (t-matrix-node-linenum (line-number-at-pos (treesit-node-start t-matrix-node)))
                    (first-col-extra (matlab-ts-mode--ei-m-matrix-first-col-extra t-matrix-node))
                    (col-widths (matlab-ts-mode--ei-m-matrix-col-widths t-matrix-node
                                                                        first-col-extra)))
-              ;; Move to the line of interest when directly indenting a line rather than a region.
+              ;; Move to the line of interest when we called from matlab-ts-mode--treesit-indent,
+              ;; otherwise calculate all matrix rows for indent-region.
               (when (and (not matrix-alist)
                          (> t-buf-ei-linenum 1))
                 (forward-line (1- t-buf-ei-linenum)))
@@ -967,22 +936,17 @@ region.  START-PT-LINENUM may be different from current line."
                 (let* ((row-node (when (>= t-curr-linenum t-matrix-node-linenum)
                                    (matlab-ts-mode--ei-get-m-matrix-row-in-line
                                     (when (= t-curr-linenum t-matrix-node-linenum) t-matrix-node))))
-                       (indent-offset (when (looking-at "[^ \t\n\r]+") (matlab--ei-offset)))
-                       ei-line
-                       pt-offset)
+                       (indent-offset (when (looking-at "[^ \t\n\r]+") (current-column)))
+                       ei-line)
                   (matlab--eilb-setup)
                   (if (and row-node indent-offset)
                       (let* ((col-num (length col-widths)) ;; Iterate last col down to first col
                              (indent-start-pt (point))
                              (r-content (buffer-substring indent-start-pt (pos-eol)))
+                             (pt-offset (nth 1 ei-info))
                              (matrix-offset (save-excursion
                                               (goto-char (treesit-node-start t-matrix-node))
                                               (1+ (- (point) (pos-bol))))))
-                        (setq pt-offset (if start-pt-linenum
-                                            (when (= t-buf-start-pt-linenum t-curr-linenum)
-                                              t-buf-start-pt-offset)
-                                          (nth 1 ei-info)))
-
                         ;; Adjust matrix row in eilb using r-content w/o leading indent-level spaces
                         (with-current-buffer matlab--eilb
                           (insert r-content))
@@ -1031,7 +995,7 @@ region.  START-PT-LINENUM may be different from current line."
 
                   (when matrix-alist
                     (let* ((buf-linenum (1- (+ assign-start-linenum t-buf-row-linenum))))
-                      (push `(,buf-linenum . ,(list ei-line pt-offset)) matrix-alist)))
+                      (push `(,buf-linenum . ,ei-line) matrix-alist)))
 
                   (if (not matrix-alist)
                       (goto-char (point-max))
@@ -1619,15 +1583,12 @@ See `matlab-ts-mode--ei-get-new-line' for EI-INFO contents."
               (setq ei-info (list ei-line new-pt-offset (nth 2 ei-info) (nth 3 ei-info))))))))
     ei-info))
 
-(defun matlab-ts-mode--ei-align (ei-info &optional start-pt-linenum start-pt-offset)
+(defun matlab-ts-mode--ei-align (ei-info)
   "Align elements in EI-INFO.
-See `matlab-ts-mode--ei-get-new-line' for EI-INFO contents.
-Optional START-PT-LINENUM and START-PT-OFFSET give the point prior to electric
-indent region."
+See `matlab-ts-mode--ei-get-new-line' for EI-INFO contents."
   (let ((matrix-assign-node (matlab-ts-mode--ei-point-in-m-type ei-info 'm-matrix)))
     (if matrix-assign-node
-        (setq ei-info (matlab-ts-mode--ei-align-line-in-m-matrix matrix-assign-node ei-info
-                                                                 start-pt-linenum start-pt-offset))
+        (setq ei-info (matlab-ts-mode--ei-align-line-in-m-matrix matrix-assign-node ei-info))
       (let ((tuple (matlab-ts-mode--ei-point-in-m-type ei-info 'm-struct)))
         (if tuple
             (setq ei-info (matlab-ts-mode--ei-align-line-in-m-struct tuple ei-info))
@@ -1637,11 +1598,8 @@ indent region."
           (setq ei-info (matlab-ts-mode--ei-align-trailing-comments ei-info))))))
   ei-info)
 
-(defun matlab-ts-mode--ei-get-start-info (start-pt-linenum start-pt-offset)
+(defun matlab-ts-mode--ei-get-start-info ()
   "Get start node and start offset in line prior to electric indent.
-If START-PT-LINENUM and START-PT-OFFSET are non-nil, the give point
-prior to electric indent.
-
 Returns (cons start-node start-offset) where
 - start-node is non-nil if the point is at a node and start-node will
   be the modified node from `matlab-ts-mode--ei-get-node-to-use'
@@ -1649,27 +1607,11 @@ Returns (cons start-node start-offset) where
 Example where point is on the \"d\" in width:
   area = width * length;
            ^
-start-node is the identifier node for width and start-offset is 2.
-If start point is at end-of-line, (cons nil nil) is returned because we
-need to just move the point to the end of the electric indented line."
+start-node is the identifier node for width and start-offset is 2."
   (let (start-node
         start-offset)
-    (save-excursion
-      (when start-pt-linenum
-        (goto-char (point-min))
-        (forward-line (1- start-pt-linenum))
-        (move-to-column start-pt-offset))
-
-      (when (not (looking-at "[ \t]*$")) ;; when not at EOL
-        (let ((new-start-pt (save-excursion
-                              (let ((start-pt (point)))
-                                (forward-line 0)
-                                (when (and (re-search-forward "[^ \t]" (pos-eol) t)
-                                           (> (point) start-pt))
-                                  (backward-char)
-                                  (point))))))
-          (when new-start-pt
-            (goto-char new-start-pt)))
+    (when (not (looking-at "[ \t]*$")) ;; when not at EOL
+      (save-excursion
         (let ((node (car (matlab-ts-mode--ei-get-node-to-use (treesit-node-at (point) 'matlab)))))
           (when (not (and node
                           (>= (point) (treesit-node-start node))
@@ -1678,7 +1620,7 @@ need to just move the point to the end of the electric indented line."
               (backward-char)
               (setq node (car (matlab-ts-mode--ei-get-node-to-use
                                (treesit-node-at (point) 'matlab))))))
-          
+
           (when (and node
                      (>= (point) (treesit-node-start node))
                      (<= (point) (treesit-node-end node)))
@@ -1745,10 +1687,10 @@ TAB>  x = 123 ./1 + 567
   new:  \"%s\"
   orig: \"%s\"
   at line %d in %s"
-                                        curr-line-node-types
-                                        orig-line-node-types
-                                        linenum
-                                        (buffer-name)))))
+           curr-line-node-types
+           orig-line-node-types
+           linenum
+           (buffer-name)))))
 
 (defun matlab-ts-mode--ei-assert-line-nodes-match (start-linenum end-linenum)
   "Assert that original line node types match modified line node types.
@@ -1863,16 +1805,17 @@ Returns the region (START-LINE . END-LINE) if disabled, else nil."
                           (<= linenum region-end))
                  (cl-return region))))))
 
-(cl-defun matlab-ts-mode--ei-indent-elements-in-line (&optional is-indent-region
-                                                                start-pt-linenum start-pt-offset)
+(cl-defun matlab-ts-mode--ei-indent-elements-in-line (&optional is-indent-region start-pt-offset)
   "Indent current line by adjusting spacing around elements.
 
 When IS-INDENT-REGION is t, we return tuple
 
   (list NEW-LINE UPDATED NEW-START-PT-OFFSET)
 
-Optional START-PT-LINENUM and START-PT-OFFSET, is used when
-IS-INDENT-REGION is t to compute NEW-START-PT-OFFSET for that line.
+Optional START-PT-OFFSET is used only when IS-INDENT-REGION is t and
+when START-PT-OFFSET is non-nil NEW-START-PT-OFFSET is non-nil.  This is
+used to update the point location for
+`matlab-ts-mode-prog-fill-reindent-defun'.
 
 When IS-INDENT-REGION is nil, we update the line and restore the point
 to it's logical location when the line is updated."
@@ -1880,29 +1823,27 @@ to it's logical location when the line is updated."
   (when (matlab-ts-mode--ei-in-disabled-region)
     (cl-return-from matlab-ts-mode--ei-indent-elements-in-line))
 
-  (let* ((start-node-and-offset
-          (when (or (not is-indent-region)
-                    (and start-pt-linenum (= start-pt-linenum (line-number-at-pos))))
-            (matlab-ts-mode--ei-get-start-info start-pt-linenum start-pt-offset)))
-         (start-node (car start-node-and-offset)) ;; may be nil
+  ;; If line was indented (nth 0 ei-info) is not same as current line, then update the buffer
+  (let* ((start-pair (when (or (not is-indent-region) start-pt-offset)
+                       (matlab-ts-mode--ei-get-start-info)))
+         (start-node (car start-pair)) ;; may be nil
          (orig-line (buffer-substring (pos-bol) (pos-eol)))
-         cached-ei-info
+         cached-ei-line
          ei-info
          result)
 
     (if (and matlab-ts-mode--ei-align-matrix-alist
-             (setq cached-ei-info
+             (setq cached-ei-line
                    (alist-get (line-number-at-pos) matlab-ts-mode--ei-align-matrix-alist)))
         ;; TopTester: test-matlab-ts-mode-electric-indent-files/electric_indent_matrix_cols.m
-        (setq ei-info cached-ei-info)
-      (setq ei-info (matlab-ts-mode--ei-get-new-line start-node (cdr start-node-and-offset))))
+        (setq ei-info (list cached-ei-line))
+      (setq ei-info (matlab-ts-mode--ei-get-new-line start-node (cdr start-pair))))
 
     (if ei-info
         (setq result
               (progn
-                (when (and (not cached-ei-info) matlab-ts-mode--ei-align-enabled)
-                  (setq ei-info (matlab-ts-mode--ei-align ei-info
-                                                          start-pt-linenum start-pt-offset)))
+                (when (and (not cached-ei-line) matlab-ts-mode--ei-align-enabled)
+                  (setq ei-info (matlab-ts-mode--ei-align ei-info)))
                 (let* ((ei-line (or (nth 0 ei-info) orig-line))
                        (pt-offset (nth 1 ei-info)) ;; non-nil if start-offset is non-nil
                        (orig-line-node-types (nth 2 ei-info))
@@ -1929,7 +1870,7 @@ to it's logical location when the line is updated."
                     ))))
       ;; else nothing updated
       (when is-indent-region
-        (setq result (list orig-line))))
+        (setq result (list orig-line 0 nil))))
 
     (when (not is-indent-region)
       (matlab--eilb-kill))
@@ -1990,7 +1931,10 @@ NEW-CONTENT-BUF is used to electric indent BEG to END region."
     (let* ((max-end-linenum (= end-linenum (line-number-at-pos (point-max))))
            (start-pt (point))
            (start-pt-linenum (line-number-at-pos start-pt))
-           (start-pt-offset (matlab--ei-offset start-pt)))
+           (start-pt-offset (- start-pt (save-excursion
+                                          (goto-char start-pt)
+                                          ;; offset from beginning of start-pt-linenum
+                                          (pos-bol)))))
       (save-excursion
         (save-restriction
           (widen)
@@ -2020,17 +1964,17 @@ NEW-CONTENT-BUF is used to electric indent BEG to END region."
                   ;; else: electric indent the line
                   (forward-line 0)
                   (let* ((tuple (matlab-ts-mode--ei-indent-elements-in-line
-                                 'indent-region start-pt-linenum start-pt-offset))
+                                 'indent-region
+                                 (when (= i-linenum start-pt-linenum)
+                                   (move-to-column start-pt-offset)
+                                   start-pt-offset)))
                          (new-line (nth 0 tuple))
                          (line-updated (nth 1 tuple))
                          (new-start-pt-offset (nth 2 tuple)))
                     (with-current-buffer new-content-buf
                       (insert new-line line-ending))
-                    (when (= i-linenum start-pt-linenum)
-                      (if new-start-pt-offset
-                          (setq start-pt-offset new-start-pt-offset)
-                        (when line-updated
-                          (setq start-pt-offset (length new-line)))))
+                    (when new-start-pt-offset
+                      (setq start-pt-offset new-start-pt-offset))
                     (when line-updated
                       (setq region-updated t)))))
               (forward-line)
